@@ -32,12 +32,12 @@ pub struct ComponentAccessor<P: Protocolize, R: ReplicateSafe<P>> {
 }
 
 impl<P: 'static + Protocolize, R: ReplicateSafe<P>> ComponentAccessor<P, R> {
-    pub fn new() -> Box<dyn Any> {
+    pub fn create() -> Box<dyn Any> {
         let inner_box: Box<dyn ComponentAccess<P>> = Box::new(ComponentAccessor {
             phantom_p: PhantomData::<P>,
             phantom_r: PhantomData::<R>,
         });
-        return Box::new(inner_box);
+        Box::new(inner_box)
     }
 }
 
@@ -52,7 +52,7 @@ impl<P: Protocolize, R: ReplicateSafe<P>> ComponentAccess<P> for ComponentAccess
             let component_dyn_ref = ReplicaDynRefWrapper::new(wrapper);
             return Some(component_dyn_ref);
         }
-        return None;
+        None
     }
 
     fn component_mut<'w>(
@@ -65,14 +65,14 @@ impl<P: Protocolize, R: ReplicateSafe<P>> ComponentAccess<P> for ComponentAccess
             let component_dyn_mut = ReplicaDynMutWrapper::new(wrapper);
             return Some(component_dyn_mut);
         }
-        return None;
+        None
     }
 
     fn remove_component(&self, world: &mut World, entity: &Entity) -> Option<P> {
         return world
             .entity_mut(*entity)
             .remove::<R>()
-            .map_or(None, |v| Some(v.into_protocol()));
+            .map(|v| v.into_protocol());
     }
 
     fn mirror_components(
