@@ -4,7 +4,9 @@ pub struct Flag {
 
 impl Flag {
     pub fn new() -> Self {
-        Self { set: false }
+        Self {
+            set: false,
+        }
     }
 
     pub fn set(&mut self) {
@@ -16,6 +18,6 @@ impl Flag {
     }
 
     pub fn is_set(&self) -> bool {
-        return self.set;
+        self.set
     }
-}
+}
\ No newline at end of file
