@@ -1,28 +1,33 @@
 use std::{
     any::Any,
     collections::{HashMap, HashSet},
+    default::Default,
 };
 
-use bevy_ecs::entity::Entity;
+use bevy_ecs::{world::{FromWorld, World}, entity::Entity};
 
 use naia_shared::{Protocolize, ReplicateSafe};
 
 use super::component_access::{ComponentAccess, ComponentAccessor};
 
-#[derive(Debug)]
 pub struct WorldData<P: Protocolize> {
     entities: HashSet<Entity>,
     kind_to_accessor_map: HashMap<P::Kind, Box<dyn Any>>,
 }
 
-impl<P: Protocolize> WorldData<P> {
-    pub fn new() -> Self {
-        WorldData {
-            entities: HashSet::new(),
-            kind_to_accessor_map: HashMap::new(),
+unsafe impl<P: Protocolize> Send for WorldData<P> {}
+unsafe impl<P: Protocolize> Sync for WorldData<P> {}
+
+impl<P: Protocolize> FromWorld for WorldData<P> {
+    fn from_world(_world: &mut World) -> Self {
+        Self {
+            entities: HashSet::default(),
+            kind_to_accessor_map: HashMap::default(),
         }
     }
+}
 
+impl<P: Protocolize> WorldData<P> {
     // Entities //
 
     pub(crate) fn entities(&self) -> Vec<Entity> {
@@ -32,7 +37,7 @@ impl<P: Protocolize> WorldData<P> {
             output.push(*entity);
         }
 
-        return output;
+        output
     }
 
     pub(crate) fn spawn_entity(&mut self, entity: &Entity) {
@@ -40,11 +45,12 @@ impl<P: Protocolize> WorldData<P> {
     }
 
     pub(crate) fn despawn_entity(&mut self, entity: &Entity) {
-        self.entities.remove(&entity);
+        self.entities.remove(entity);
     }
 
     // Components
 
+    #[allow(clippy::borrowed_box)]
     pub(crate) fn component_access(
         &self,
         component_kind: &P::Kind,
@@ -52,18 +58,15 @@ impl<P: Protocolize> WorldData<P> {
         if let Some(accessor_any) = self.kind_to_accessor_map.get(component_kind) {
             return accessor_any.downcast_ref::<Box<dyn ComponentAccess<P>>>();
         }
-        return None;
+        None
     }
 
     pub(crate) fn has_kind(&self, component_kind: &P::Kind) -> bool {
-        return self.kind_to_accessor_map.contains_key(component_kind);
+        self.kind_to_accessor_map.contains_key(component_kind)
     }
 
     pub(crate) fn put_kind<R: ReplicateSafe<P>>(&mut self, component_kind: &P::Kind) {
         self.kind_to_accessor_map
-            .insert(*component_kind, ComponentAccessor::<P, R>::new());
+            .insert(*component_kind, ComponentAccessor::<P, R>::create());
     }
 }
-
-unsafe impl<P: Protocolize> Send for WorldData<P> {}
-unsafe impl<P: Protocolize> Sync for WorldData<P> {}
