@@ -22,7 +22,7 @@ pub trait WorldProxy<'w> {
 
 impl<'w> WorldProxy<'w> for &'w World {
     fn proxy(self) -> WorldRef<'w> {
-        return WorldRef::new(self);
+        WorldRef::new(self)
     }
 }
 
@@ -34,7 +34,7 @@ pub trait WorldProxyMut<'w> {
 
 impl<'w> WorldProxyMut<'w> for &'w mut World {
     fn proxy_mut(self) -> WorldMut<'w> {
-        return WorldMut::new(self);
+        WorldMut::new(self)
     }
 }
 
@@ -52,23 +52,23 @@ impl<'w> WorldRef<'w> {
 
 impl<'w, P: Protocolize> WorldRefType<P, Entity> for WorldRef<'w> {
     fn has_entity(&self, entity: &Entity) -> bool {
-        return has_entity(self.world, entity);
+        has_entity(self.world, entity)
     }
 
     fn entities(&self) -> Vec<Entity> {
-        return entities::<P>(self.world);
+        entities::<P>(self.world)
     }
 
     fn has_component<R: ReplicateSafe<P>>(&self, entity: &Entity) -> bool {
-        return has_component::<P, R>(self.world, entity);
+        has_component::<P, R>(self.world, entity)
     }
 
     fn has_component_of_kind(&self, entity: &Entity, component_kind: &P::Kind) -> bool {
-        return has_component_of_kind::<P>(self.world, entity, component_kind);
+        has_component_of_kind::<P>(self.world, entity, component_kind)
     }
 
     fn component<R: ReplicateSafe<P>>(&self, entity: &Entity) -> Option<ReplicaRefWrapper<P, R>> {
-        return component(self.world, entity);
+        component(self.world, entity)
     }
 
     fn component_of_kind(
@@ -76,7 +76,7 @@ impl<'w, P: Protocolize> WorldRefType<P, Entity> for WorldRef<'w> {
         entity: &Entity,
         component_kind: &P::Kind,
     ) -> Option<ReplicaDynRefWrapper<P>> {
-        return component_of_kind::<P>(self.world, entity, component_kind);
+        component_of_kind::<P>(self.world, entity, component_kind)
     }
 }
 
@@ -94,23 +94,23 @@ impl<'w> WorldMut<'w> {
 
 impl<'w, P: Protocolize> WorldRefType<P, Entity> for WorldMut<'w> {
     fn has_entity(&self, entity: &Entity) -> bool {
-        return has_entity(self.world, entity);
+        has_entity(self.world, entity)
     }
 
     fn entities(&self) -> Vec<Entity> {
-        return entities::<P>(self.world);
+        entities::<P>(self.world)
     }
 
     fn has_component<R: ReplicateSafe<P>>(&self, entity: &Entity) -> bool {
-        return has_component::<P, R>(self.world, entity);
+        has_component::<P, R>(self.world, entity)
     }
 
     fn has_component_of_kind(&self, entity: &Entity, component_kind: &P::Kind) -> bool {
-        return has_component_of_kind::<P>(self.world, entity, component_kind);
+        has_component_of_kind::<P>(self.world, entity, component_kind)
     }
 
     fn component<R: ReplicateSafe<P>>(&self, entity: &Entity) -> Option<ReplicaRefWrapper<P, R>> {
-        return component(self.world, entity);
+        component(self.world, entity)
     }
 
     fn component_of_kind(
@@ -118,7 +118,7 @@ impl<'w, P: Protocolize> WorldRefType<P, Entity> for WorldMut<'w> {
         entity: &Entity,
         component_kind: &P::Kind,
     ) -> Option<ReplicaDynRefWrapper<P>> {
-        return component_of_kind(self.world, entity, component_kind);
+        component_of_kind(self.world, entity, component_kind)
     }
 }
 
@@ -126,10 +126,10 @@ impl<'w, P: Protocolize> WorldMutType<P, Entity> for WorldMut<'w> {
     fn spawn_entity(&mut self) -> Entity {
         let entity = self.world.spawn().id();
 
-        let mut world_data = world_data_unchecked_mut::<P>(&mut self.world);
+        let mut world_data = world_data_unchecked_mut::<P>(self.world);
         world_data.spawn_entity(&entity);
 
-        return entity;
+        entity
     }
 
     fn duplicate_entity(&mut self, entity: &Entity) -> Entity {
@@ -141,9 +141,9 @@ impl<'w, P: Protocolize> WorldMutType<P, Entity> for WorldMut<'w> {
     }
 
     fn duplicate_components(&mut self, mutable_entity: &Entity, immutable_entity: &Entity) {
-        for component_kind in WorldMutType::<P, Entity>::component_kinds(self, &immutable_entity) {
+        for component_kind in WorldMutType::<P, Entity>::component_kinds(self, immutable_entity) {
             let mut component_copy_opt: Option<P> = None;
-            if let Some(component) = self.component_of_kind(&immutable_entity, &component_kind) {
+            if let Some(component) = self.component_of_kind(immutable_entity, &component_kind) {
                 component_copy_opt = Some(component.protocol_copy());
             }
             if let Some(component_copy) = component_copy_opt {
@@ -153,7 +153,7 @@ impl<'w, P: Protocolize> WorldMutType<P, Entity> for WorldMut<'w> {
     }
 
     fn despawn_entity(&mut self, entity: &Entity) {
-        let mut world_data = world_data_unchecked_mut::<P>(&self.world);
+        let mut world_data = world_data_unchecked_mut::<P>(self.world);
         world_data.despawn_entity(entity);
 
         self.world.despawn(*entity);
@@ -176,7 +176,7 @@ impl<'w, P: Protocolize> WorldMutType<P, Entity> for WorldMut<'w> {
             }
         }
 
-        return kinds;
+        kinds
     }
 
     fn component_mut<R: ReplicateSafe<P>>(
@@ -188,7 +188,7 @@ impl<'w, P: Protocolize> WorldMutType<P, Entity> for WorldMut<'w> {
             let component_mut = ReplicaMutWrapper::new(wrapper);
             return Some(component_mut);
         }
-        return None;
+        None
     }
 
     fn component_apply_update(
@@ -209,7 +209,7 @@ impl<'w, P: Protocolize> WorldMutType<P, Entity> for WorldMut<'w> {
     }
 
     fn mirror_entities(&mut self, new_entity: &Entity, old_entity: &Entity) {
-        for component_kind in WorldMutType::<P, Entity>::component_kinds(self, &old_entity) {
+        for component_kind in WorldMutType::<P, Entity>::component_kinds(self, old_entity) {
             WorldMutType::<P, Entity>::mirror_components(
                 self,
                 new_entity,
@@ -236,7 +236,7 @@ impl<'w, P: Protocolize> WorldMutType<P, Entity> for WorldMut<'w> {
     fn insert_component<I: ReplicateSafe<P>>(&mut self, entity: &Entity, component_ref: I) {
         // cache type id for later
         // todo: can we initialize this map on startup via Protocol derive?
-        let mut world_data = world_data_unchecked_mut(&self.world);
+        let mut world_data = world_data_unchecked_mut(self.world);
         let component_kind = component_ref.kind();
         if !world_data.has_kind(&component_kind) {
             world_data.put_kind::<I>(&component_kind);
@@ -258,7 +258,7 @@ impl<'w, P: Protocolize> WorldMutType<P, Entity> for WorldMut<'w> {
                     output = accessor.remove_component(world, entity);
                 }
             });
-        return output;
+        output
     }
 }
 
@@ -276,7 +276,7 @@ fn has_entity(world: &World, entity: &Entity) -> bool {
 
 fn entities<P: Protocolize>(world: &World) -> Vec<Entity> {
     let world_data = world_data::<P>(world);
-    return world_data.entities();
+    world_data.entities()
 }
 
 fn has_component<P: Protocolize, R: ReplicateSafe<P>>(world: &World, entity: &Entity) -> bool {
@@ -302,7 +302,7 @@ fn component<'a, P: Protocolize, R: ReplicateSafe<P>>(
         let component_ref = ReplicaRefWrapper::new(wrapper);
         return Some(component_ref);
     }
-    return None;
+    None
 }
 
 fn component_of_kind<'a, P: Protocolize>(
@@ -314,7 +314,7 @@ fn component_of_kind<'a, P: Protocolize>(
     if let Some(component_access) = world_data.component_access(component_kind) {
         return component_access.component(world, entity);
     }
-    return None;
+    None
 }
 
 fn world_data<P: Protocolize>(world: &World) -> &WorldData<P> {
